Index: host/include/host_key.h |
diff --git a/host/include/host_key.h b/host/include/host_key.h |
index 9ce1fa56711f9cca8510556f87cbf3ca7b6f7642..e7b18155f415ab73142af6b8479c09d79dfb9d5e 100644 |
--- a/host/include/host_key.h |
+++ b/host/include/host_key.h |
@@ -22,9 +22,9 @@ typedef struct VbPrivateKey { |
} VbPrivateKey; |
/* Read a private key from a file. Caller owns the returned pointer, |
* and must free it with PrivateKeyFree(). */ |
-VbPrivateKey* PrivateKeyRead(const char* filename, uint64_t algorithm); |
+VbPrivateKey* PrivateKeyReadPem(const char* filename, uint64_t algorithm); |
/* Free a private key. */ |
@@ -22,9 +22,9 @@ typedef struct VbPrivateKey { |
} VbPrivateKey; |
-/* Read a private key from a file. Caller owns the returned pointer, |
+/* Read a private key from a .pem file. Caller owns the returned pointer, |
* and must free it with PrivateKeyFree(). */ |